@@ -512,6 +512,14 @@ static int read_config_cb(char *fname, void *data)
      return 1;
 }
 
+static int find_plugger_helper_cb(char *fname, void *data)
+{
+     struct stat buf;
+     if (stat(fname, &buf)) return 0;
+     helper_fname = strdup(fname);
+     return 1;
+}
+
 /*****************************************************************************
  * Find configuration file and read it into memory.
  *****************************************************************************/
@@ -527,12 +535,14 @@ static void do_read_config(void)
 	  return;
      }
 
-     if (!find("mozplugger"))
+     if (find("mozplugger")) helper_fname = "mozplugger";
+     find_helper_file("mozplugger", find_plugger_helper_cb, 0);
+
+     if (!helper_fname)
      {
 	  fprintf(stderr, "MozPlugger: Unable to find the mozplugger helper.\n");
 	  return;
      }
-     helper_fname = "mozplugger";
 
      D("do_read_config done\n");
 }
