@@ -22,6 +22,14 @@
 #define MAXINT 0x7fffffff
 #endif
 
+/*****************************************************************************
+ * Swallow loop parameters
+ *****************************************************************************/
+#define SWALLOW_LOOPS     4000
+/* Do not increase this wait time or the swallow will not work
+ * correctly on some computers. */
+#define SWALLOW_WAIT_TIME 500
+
 /*****************************************************************************
  * Options
  *****************************************************************************/
